@@ -10,7 +10,8 @@ from typing import Any, Dict, Optional, Union
 import numpy as np
 from memory_profiler import memory_usage
 from monty.json import MSONable
-from pymatgen import Structure, loadfn
+from monty.serialization import loadfn
+from pymatgen.core.structure import Structure
 from pymatgen.electronic_structure.bandstructure import BandStructure
 from pymatgen.electronic_structure.core import Spin
 from pymatgen.io.vasp import Vasprun
@@ -69,15 +70,15 @@ class Runner(MSONable):
         log_banner("END")
 
         logger.info("Timing and memory usage:")
-        timing_info = ["{} time: {:.4f} s".format(n, t) for n, t in usage_stats.items()]
-        log_list(timing_info + ["max memory: {:.1f} MB".format(mem_usage)])
+        timing_info = [f"{n} time: {t:.4f} s" for n, t in usage_stats.items()]
+        log_list(timing_info + [f"max memory: {mem_usage:.1f} MB"])
 
         this_date = datetime.datetime.now().strftime("%d %b %Y")
         this_time = datetime.datetime.now().strftime("%H:%M")
-        logger.info("amset exiting on {} at {}".format(this_date, this_time))
+        logger.info(f"amset exiting on {this_date} at {this_time}")
 
         if return_usage_stats:
-            usage_stats["max memory"] = mem_usage
+            usage_stats["max_memory"] = mem_usage
             return amset_data, usage_stats
         else:
             return amset_data
@@ -87,7 +88,7 @@ class Runner(MSONable):
     ):
         if self.settings["print_log"] or self.settings["write_log"]:
             if self.settings["write_log"]:
-                log_file = "{}_amset.log".format(prefix) if prefix else "amset.log"
+                log_file = f"{prefix}_amset.log" if prefix else "amset.log"
             else:
                 log_file = False
 
@@ -152,10 +153,10 @@ class Runner(MSONable):
             amset_data.calculate_fd_cutoffs(
                 fd_tol, cutoff_pad=cutoff_pad, mobility_rates_only=mobility_rates_only
             )
-            fd_prefix = prefix + "fd-{}".format(fd_tol)
+            fd_prefix = prefix + f"fd-{fd_tol}"
             _, timing = self._do_fd_tol(amset_data, directory, fd_prefix, timing)
-            timing["transport ({})".format(fd_tol)] = timing.pop("transport")
-            timing["writing ({})".format(fd_tol)] = timing.pop("writing")
+            timing[f"transport ({fd_tol})"] = timing.pop("transport")
+            timing[f"writing ({fd_tol})"] = timing.pop("writing")
 
         return amset_data, timing
 
@@ -313,7 +314,7 @@ class Runner(MSONable):
             else:
                 full_filename = Path(abs_dir) / filename
 
-            logger.info("Results written to:\n{}".format(full_filename))
+            logger.info(f"Results written to:\n{full_filename}")
         return full_filename, time.perf_counter() - t0
 
     @staticmethod
@@ -408,8 +409,10 @@ def _log_amset_intro():
 
                                                   v{}
 
-    A. Ganose, J. Park, A. Faghaninia, R. Woods-Robinson,
-    A. Jain, in prep.
+    Ganose, A. M., Park, J., Faghaninia, A., Woods-Robinson,
+    R., Persson, K. A., Jain, A. Efficient calculation of
+    carrier scattering rates from first principles.
+    Nat. Commun. 12, 2222 (2021)
 
 
 amset starting on {} at {}""".format(
@@ -433,9 +436,9 @@ def _log_structure_information(structure: Structure, symprec):
     spg = unicodeify_spacegroup(sga.get_space_group_symbol())
 
     comp_info = [
-        "formula: {}".format(unicodeify(formula)),
-        "# sites: {}".format(structure.num_sites),
-        "space group: {}".format(spg),
+        f"formula: {unicodeify(formula)}",
+        f"# sites: {structure.num_sites}",
+        f"space group: {spg}",
     ]
     log_list(comp_info)
 
@@ -483,7 +486,7 @@ def _log_settings(runner: Runner):
 
     log_banner("SETTINGS")
     logger.info("Run parameters:")
-    p = ["{}: {}".format(k, ff(v)) for k, v in runner.settings.items() if v is not None]
+    p = [f"{k}: {ff(v)}" for k, v in runner.settings.items() if v is not None]
     log_list(p)
 
 
@@ -491,11 +494,11 @@ def _log_band_structure_information(band_structure: BandStructure):
     log_banner("BAND STRUCTURE")
 
     info = [
-        "# bands: {}".format(band_structure.nb_bands),
-        "# k-points: {}".format(len(band_structure.kpoints)),
-        "Fermi level: {:.3f} eV".format(band_structure.efermi),
-        "spin polarized: {}".format(band_structure.is_spin_polarized),
-        "metallic: {}".format(band_structure.is_metal()),
+        f"# bands: {band_structure.nb_bands}",
+        f"# k-points: {len(band_structure.kpoints)}",
+        f"Fermi level: {band_structure.efermi:.3f} eV",
+        f"spin polarized: {band_structure.is_spin_polarized}",
+        f"metallic: {band_structure.is_metal()}",
     ]
     logger.info("Input band structure information:")
     log_list(info)
@@ -511,8 +514,8 @@ def _log_band_structure_information(band_structure: BandStructure):
         band_gap_info.append("indirect band gap: {:.3f} eV".format(bg_data["energy"]))
 
     direct_data = band_structure.get_direct_band_gap_dict()
-    direct_bg = min((spin_data["value"] for spin_data in direct_data.values()))
-    band_gap_info.append("direct band gap: {:.3f} eV".format(direct_bg))
+    direct_bg = min(spin_data["value"] for spin_data in direct_data.values())
+    band_gap_info.append(f"direct band gap: {direct_bg:.3f} eV")
 
     direct_kpoint = []
     for spin, spin_data in direct_data.items():
@@ -545,7 +548,7 @@ def _log_band_edge_information(band_structure, edge_data):
         spins = edge_data["band_index"].keys()
         b_indices = [
             ", ".join([str(i + 1) for i in edge_data["band_index"][spin]])
-            + "({})".format(spin.name.capitalize())
+            + f"({spin.name.capitalize()})"
             for spin in spins
         ]
         b_indices = ", ".join(b_indices)
@@ -557,8 +560,8 @@ def _log_band_edge_information(band_structure, edge_data):
 
     info = [
         "energy: {:.3f} eV".format(edge_data["energy"]),
-        "k-point: {}".format(kpoint_str),
-        "band indices: {}".format(b_indices),
+        f"k-point: {kpoint_str}",
+        f"band indices: {b_indices}",
     ]
     log_list(info)
 
